==========
References
==========


Python Standard library
=======================

-  itertools_: The Python standard library for iterator tools.
-  functools_: The Python standard library for function tools.
-  operator_: Python operator as functions.

.. _itertools: http://docs.python.org/3/library/itertools.html
.. _functools: http://docs.python.org/3/library/functools.html
.. _operator: http://docs.python.org/3/library/operator.html

Other Python projects
=====================

These projects also provide functional utilities within Python. Their functionality sometimes
overlaps with Sidekick, and they often can be used together very naturally.

* Toolz_: Excellent library centered around iterators.
* Funcy_: Library somewhat inspired in Underscore.js.
* `Fn.py`_: Interesting library with some Haskelisms.
* `More itertools`_: Extend itertools with many more functions.

.. _Toolz: https://toolz.readthedocs.io/en/stable/
.. _Funcy: https://funcy.readthedocs.io/en/stable/
.. _Fn.py: https://github.com/kachayev/fn.py
.. _More itertools: https://more-itertools.readthedocs.io/en/stable/


Other influential libraries and programming languages
=====================================================

- Clojure_: A functional language whose standard library has several counterparts in ``sidekick``.
- Elixir_: A functional language inspired both in Ruby and in Erlang
- `Underscore.js`_: A very popular FP library for JavaScript

.. _Clojure: http://clojure.org
.. _Elixir: https://hexdocs.pm/elixir/
.. _Underscore.js: http://underscorejs.org


Other resources
===============


- `Awesome functional programming`_: List of links and other resources related to FP in Python.
- `Functional Programming HOWTO`_: The description of functional programming features from the official Python docs.

.. _Awesome functional programming: https://github.com/sfermigier/awesome-functional-python
.. _Functional Programming HOWTO: http://docs.python.org/dev/howto/functional.html
